|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r56086 - in trunk/boost/spirit/home/lex/lexer: . lexertl
From: hartmut.kaiser_at_[hidden]
Date: 2009-09-07 10:39:26
Author: hkaiser
Date: 2009-09-07 10:39:25 EDT (Mon, 07 Sep 2009)
New Revision: 56086
URL: http://svn.boost.org/trac/boost/changeset/56086
Log:
Spirit: removed lex::omitted in favor of lex::omit
Text files modified:
trunk/boost/spirit/home/lex/lexer/lexertl/token.hpp | 18 +++++++++---------
trunk/boost/spirit/home/lex/lexer/terminals.hpp | 3 ++-
2 files changed, 11 insertions(+), 10 deletions(-)
Modified: trunk/boost/spirit/home/lex/lexer/lexertl/token.hpp
==============================================================================
--- trunk/boost/spirit/home/lex/lexer/terminals.hpp (original)
+++ trunk/boost/spirit/home/lex/lexer/terminals.hpp 2009-09-07 10:39:25 EDT (Mon, 07 Sep 2009)
@@ -16,7 +16,8 @@
{
///////////////////////////////////////////////////////////////////////////
// Define a more convenient name for an omitted token attribute type
- typedef omit_type omitted;
+ using spirit::omit;
+ using spirit::omit_type;
}}}
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- trunk/boost/spirit/home/lex/lexer/lexertl/token.hpp (original)
+++ trunk/boost/spirit/home/lex/lexer/lexertl/token.hpp 2009-09-07 10:39:25 EDT (Mon, 07 Sep 2009)
@@ -112,7 +112,7 @@
// doesn't support working with lexer states.
///////////////////////////////////////////////////////////////////////////
template <typename Iterator>
- struct token<Iterator, omitted, mpl::false_>
+ struct token<Iterator, omit, mpl::false_>
{
typedef Iterator iterator_type;
typedef mpl::false_ has_state;
@@ -188,11 +188,11 @@
// supports working with lexer states.
///////////////////////////////////////////////////////////////////////////
template <typename Iterator>
- struct token<Iterator, omitted, mpl::true_>
- : token<Iterator, omitted, mpl::false_>
+ struct token<Iterator, omit, mpl::true_>
+ : token<Iterator, omit, mpl::false_>
{
private:
- typedef token<Iterator, omitted, mpl::false_> base_type;
+ typedef token<Iterator, omit, mpl::false_> base_type;
public:
typedef typename base_type::id_type id_type;
@@ -256,7 +256,7 @@
// The type of the data item stored with a token instance is defined
// by the template parameter 'AttributeTypes' and may be:
//
// omitted: no data item is stored with the token
// instance (this is handled by the
// specializations of the token class
// below)
@@ -283,14 +283,14 @@
}
template <typename Iterator, typename AttributeTypes, typename HasState>
- struct token : token<Iterator, omitted, HasState>
+ struct token : token<Iterator, omit, HasState>
{
private: // precondition assertions
#if !BOOST_WORKAROUND(BOOST_MSVC, <= 1300)
BOOST_STATIC_ASSERT((mpl::is_sequence<AttributeTypes>::value ||
- is_same<AttributeTypes, omitted>::value));
+ is_same<AttributeTypes, omit>::value));
#endif
- typedef token<Iterator, omitted, HasState> base_type;
+ typedef token<Iterator, omit, HasState> base_type;
protected:
// If no additional token value types are given, the the token will
@@ -456,7 +456,7 @@
// constructed values.
template <typename Attribute, typename Iterator, typename HasState>
inline void
- construct(Attribute& attr, token<Iterator, omitted, HasState>& t) {}
+ construct(Attribute& attr, token<Iterator, omit, HasState>& t) {}
// This is called from the parse function of lexer_def_
template <typename Iterator, typename AttributeTypes, typename HasState>
Modified: trunk/boost/spirit/home/lex/lexer/terminals.hpp
@@ -256,7 +256,7 @@
// by the template parameter 'AttributeTypes' and may be:
//
- // omitted: no data item is stored with the token
+ // omit: no data item is stored with the token
// instance (this is handled by the
// specializations of the token class
==============================================================================